%{?mingw_package_header}

%global _basename portmidi

Summary:        Real-time Midi I/O Library
Name:           mingw-%{_basename}
Version:        217
Release:        7%{?dist}
License:        MIT
Group:          System Environment/Libraries
URL:            http://portmedia.sourceforge.net/
Source0:        http://downloads.sourceforge.net/portmedia/%{_basename}-src-%{version}.zip
Source1:        pmdefaults.desktop
# Build fixes:
Patch0:         portmidi-cmake.patch
# Fix multilib conflict RHBZ#831432
Patch1:         portmidi-no_date_footer.patch
Patch2:         portmidi-mingw.patch
#BuildRequires:  alsa-lib-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  java-devel >= 1.7
BuildRequires:  java-1.7.0-openjdk-devel
BuildRequires:  jpackage-utils
#BuildRequires:  python2-devel
BuildRequires:  doxygen
BuildRequires:  tex(latex)

BuildArch:      noarch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-binutils

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-binutils

%description
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains the PortMidi
libraries.

%package -n mingw32-%{_basename}
Summary:        Real-time Midi I/O Library
Group:          System Environment/Libraries

%description -n mingw32-%{_basename}
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains the header files
and the documentation of PortMidi libraries.
This is the MinGW version, built for the win32 target.

%package -n mingw64-%{_basename}
Summary:        Real-time Midi I/O Library
Group:          System Environment/Libraries

%description -n mingw64-%{_basename}
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains the header files
and the documentation of PortMidi libraries.
This is the MinGW version, built for the win32 target.


%{?mingw_debug_package}


%prep
%setup -q -n %{_basename}
%patch0 -p1 -b .buildfix
%patch1 -p1 -b .no.date
%patch2 -p1

# ewwww... binaries
rm -f portmidi_cdt.zip */*.exe */*/*.exe

# Fix permissons and encoding issues:
find . -name "*.c" -exec chmod -x {} \;
find . -name "*.h" -exec chmod -x {} \;
for i in *.txt */*.txt */*/*.txt ; do
   chmod -x $i
   sed 's|\r||' $i > $i.tmp
   touch -r $i $i.tmp
   mv -f $i.tmp $i
done

# Fedora's jni library location is different
sed -i 's|loadLibrary.*|load("%{_libdir}/portmidi/libpmjni.so");|' \
   pm_java/jportmidi/JPortMidiApi.java

# Add shebang, lib and class path
sed -i -e 's|^java|#!/bin/sh\njava \\\
   -Djava.library.path=%{_libdir}/portmidi/|' \
   -e 's|/usr/share/java/|%{_libdir}/portmidi/|' \
   pm_java/pmdefaults/pmdefaults

%build
export JAVA_HOME=%{java_home}
# FindJNI.cmake is being really stupid for no apparent reason...
# so hardcode the paths
%{mingw_cmake} -DCMAKE_SKIP_BUILD_RPATH=1 \
	-DCMAKE_CACHEFILE_DIR=%{_builddir}/portmidi/build \
	-DJAVA_INCLUDE_PATH:STRING=${JAVA_HOME}/include \
	-DJAVA_INCLUDE_PATH2:STRING=${JAVA_HOME}/include/linux \
	-DJAVA_AWT_LIBRARY:STRING=${JAVA_HOME}/lib/i386 \
	-DJAVA_AWT_INCLUDE_PATH:STRING=${JAVA_HOME}/include \
	-DJAVA_JVM_LIBRARY:STRING=${JAVA_HOME}/jre/lib/i386/client \
	-DVERSION=%{version} .
%{mingw_make} %{?_smp_flags}

# Build the doxygen documentation:
doxygen

%install
%{mingw_make_install} DESTDIR=%{buildroot}

# Fedora's jni library location is different
mkdir -p %{buildroot}%{mingw32_libdir}/portmidi/
mv %{buildroot}%{mingw32_libdir}/libpmjni.dll.a \
   %{buildroot}%{mingw32_libdir}/portmidi/
mkdir -p %{buildroot}%{mingw64_libdir}/portmidi/
mv %{buildroot}%{mingw64_libdir}/libpmjni.dll.a \
   %{buildroot}%{mingw64_libdir}/portmidi/

# Not being installed under MinGW?
mkdir -p %{buildroot}%{mingw32_bindir}
install -pm 644 build_win32/libportmidi.dll \
	%{buildroot}%{mingw32_bindir}
install -pm 644 build_win32/libportmidi_s.dll \
	%{buildroot}%{mingw32_bindir}
mkdir -p %{buildroot}%{mingw64_bindir}
install -pm 644 build_win64/libportmidi.dll \
	%{buildroot}%{mingw64_bindir}
install -pm 644 build_win64/libportmidi_s.dll \
	%{buildroot}%{mingw64_bindir}

# pmdefaults icon
mkdir -p %{buildroot}%{mingw32_datadir}/icons/hicolor/128x128/apps/
install -pm 644 pm_java/pmdefaults/pmdefaults-icon.png \
   %{buildroot}%{mingw32_datadir}/icons/hicolor/128x128/apps/
mkdir -p %{buildroot}%{mingw64_datadir}/icons/hicolor/128x128/apps/
install -pm 644 pm_java/pmdefaults/pmdefaults-icon.png \
   %{buildroot}%{mingw64_datadir}/icons/hicolor/128x128/apps/

# desktop file
mkdir -p %{buildroot}%{mingw32_desktopdir}/
desktop-file-install \
   --dir=%{buildroot}%{mingw32_desktopdir} \
   %{SOURCE1}
mkdir -p %{buildroot}%{mingw64_desktopdir}/
desktop-file-install \
   --dir=%{buildroot}%{mingw64_desktopdir} \
   %{SOURCE1}

# Why don't they install this header file?
install -pm 644 pm_common/pmutil.h %{buildroot}%{mingw32_includedir}/
install -pm 644 pm_common/pmutil.h %{buildroot}%{mingw64_includedir}/

# Remove duplicate library
rm -f %{buildroot}%{mingw32_libdir}/libportmidi_s.so
rm -f %{buildroot}%{mingw64_libdir}/libportmidi_s.so

# Argh...WTF?  This hasn't happened with any other MinGW package...
cat < /dev/null > debugfiles.list

%files -n mingw32-%{_basename}
#doc CHANGELOG.txt license.txt
%{mingw32_bindir}/*.dll
#doc README.txt
#{mingw32_docdir}/html
%{mingw32_includedir}/*
%{mingw32_libdir}/lib*.a
%{mingw32_libdir}/portmidi/lib*.a
%{mingw32_datadir}/icons/hicolor/128x128/apps/pmdefaults-icon.png

%files -n mingw64-%{_basename}
#doc CHANGELOG.txt license.txt
%{mingw64_bindir}/*.dll
#doc README.txt
#{mingw64_docdir}/html
%{mingw64_includedir}/*
%{mingw64_libdir}/lib*.a
%{mingw64_libdir}/portmidi/lib*.a
%{mingw64_datadir}/icons/hicolor/128x128/apps/pmdefaults-icon.png

%changelog
* Fri May 17 2013 Steven Boswell <ulatekh@yahoo.com> - 217-7
- Ported to MinGW

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 217-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 12 2012 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 217-6
- Fix multilib conflict RHBZ#831432
- Don't bulid PDF doc, as it causes another multilib conflict
- Specfile cleanup. Drop old GCJ-Java and Python bits

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 217-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jun 23 2011 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 217-4
- Fix FTBFS due to changes in cmake. RHBZ #715668

* Sat May 14 2011 Daniel Drake <dsd@laptop.org> - 217-3
- move Requires:Java to tools subpackage, its not needed by the main package

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 217-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Oct 09 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 217-1
- Update to 217

* Fri Jul 23 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 200-4
- Fix python module build

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 200-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sat Jan 30 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 200-2
- Remove duplicate library

* Sat Jan 30 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 200-1
- Update to 200.
- Add python subpackage

* Fri Nov 27 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 184-1
- Update to 184. Build system uses cmake now.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 131-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 131-3
- Include pmutil.h in the devel package

* Tue Jan 27 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 131-2
- Build and add doxygen documentation
- Preserve some timestamps

* Sun Jan 11 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 131-1
- New upstream release.

* Sun Dec 07 2008 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> 82-1
- Initial release.
